@@ -53,6 +53,10 @@
 extern module AP_MODULE_DECLARE_DATA auth_gssapi_module;
 #define GSS_NAME_ATTR_USERDATA "GSS Name Attributes Userdata"
 
+#ifndef HAVE_AP_LOG_RDATA
+#define ap_log_rdata(...)
+#endif
+
 struct mag_na_map {
     char *env_name;
     char *attr_name;
@@ -79,7 +83,7 @@ struct mag_config {
     gid_t deleg_ccache_gid;
     gss_key_value_set_desc *cred_store;
     bool deleg_ccache_unique;
-    bool s4u2self;
+    int s4u2self;
     char *ccname_envvar;
 #endif
     struct seal_key *mag_skey;
@@ -90,9 +94,13 @@ struct mag_config {
     bool negotiate_once;
     struct mag_name_attributes *name_attributes;
     const char *required_na_expr;
-    bool enverrs;
+    int enverrs;
+    int pubmech;
     gss_name_t acceptor_name;
     bool acceptor_name_from_req;
+    uint32_t basic_timeout;
+
+    bool verified;
 };
 
 struct mag_server_config {
