@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # Copyright (C) 2015 - mod_auth_gssapi contributors, see COPYING for license.
 
 import os
-import requests
 from stat import ST_MODE
-from requests_kerberos import HTTPKerberosAuth, OPTIONAL
 
+import requests
+from requests_gssapi import HTTPKerberosAuth, OPTIONAL # noqa
 
 if __name__ == '__main__':
     sess = requests.Session()
@@ -19,5 +19,5 @@ if __name__ == '__main__':
         raise ValueError('gssapi_session not set')
 
     data = os.stat(os.environ['DELEGCCACHE'])
-    if data[ST_MODE] != 0100666:
+    if data[ST_MODE] != 0o100666:
         raise ValueError('Incorrect perm on ccache: %o' % data[ST_MODE])
