@@ -1,9 +1,10 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # Copyright (C) 2015 - mod_auth_gssapi contributors, see COPYING for license.
 
 import os
+
 import requests
-from requests_kerberos import HTTPKerberosAuth, OPTIONAL
+from requests_gssapi import HTTPKerberosAuth, OPTIONAL # noqa
 
 
 if __name__ == '__main__':
@@ -17,7 +18,7 @@ if __name__ == '__main__':
     if r.status_code != 401:
         raise ValueError('Spnego Negotiate Once failed - 401 expected')
     if not (r.headers.get("WWW-Authenticate") and
-        r.headers.get("WWW-Authenticate").startswith("Negotiate")):
+            r.headers.get("WWW-Authenticate").startswith("Negotiate")):
         raise ValueError('Spnego Negotiate Once failed - WWW-Authenticate '
                          'Negotiate header missing')
 
@@ -34,4 +35,3 @@ if __name__ == '__main__':
     r = sess.get(url, auth=HTTPKerberosAuth())
     if r.status_code != 200:
         raise ValueError('Spnego Negotiate Once failed')
-
