@@ -1,11 +1,14 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # Copyright (C) 2015 - mod_auth_gssapi contributors, see COPYING for license.
 
 import os
-import requests
-import gssapi
 from base64 import b64encode
 
+import gssapi
+
+import requests
+
+
 def getAuthToken(target):
     spnego_mech = gssapi.raw.OID.from_int_seq('1.3.6.1.5.5.2')
 
@@ -15,7 +18,7 @@ def getAuthToken(target):
     ctx = gssapi.SecurityContext(name=name, mech=spnego_mech)
     token = ctx.step()
 
-    return 'Negotiate %s' % b64encode(token)
+    return 'Negotiate %s' % b64encode(token).decode()
 
 
 if __name__ == '__main__':
@@ -25,7 +28,7 @@ if __name__ == '__main__':
     url = 'http://%s/spnego/' % target
 
     proxy = 'http://%s:%s' % (target, os.environ['WRAP_PROXY_PORT'])
-    proxies = { "http" : proxy, }
+    proxies = {"http": proxy, }
 
     s.headers.update({'Proxy-Authorization': getAuthToken(target)})
     s.headers.update({'Authorization': getAuthToken(target)})
